summaryrefslogtreecommitdiffstats
path: root/kio/kio/kdirlister_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/kdirlister_p.h')
-rw-r--r--kio/kio/kdirlister_p.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kio/kdirlister_p.h b/kio/kio/kdirlister_p.h
index a98521905..9a91e57df 100644
--- a/kio/kio/kdirlister_p.h
+++ b/kio/kio/kdirlister_p.h
@@ -70,7 +70,7 @@ public:
/**
* List of dirs handled by this dirlister. The first entry is the base URL.
- * For a tree view, it contains all the dirs shown.
+ * For a tree view, it tqcontains all the dirs shown.
*/
KURL::List lstDirs;
@@ -150,13 +150,13 @@ public:
KFileItemList *itemsForDir( const KURL &_dir ) const;
- KFileItem *findByName( const KDirLister *lister, const TQString &_name ) const;
+ KFileItem *tqfindByName( const KDirLister *lister, const TQString &_name ) const;
// if lister is set, it is checked that the url is held by the lister
KFileItem *findByURL( const KDirLister *lister, const KURL &_url ) const;
/**
* Notify that files have been added in @p directory
* The receiver will list that directory again to find
* the new items (since it needs more than just the names anyway).
* Reimplemented from KDirNotify.
*/
@@ -150,13 +150,13 @@ public:
/**
* Notify that files have been added in @p directory
- * The receiver will list that directory again to find
+ * The receiver will list that directory again to tqfind
* the new items (since it needs more than just the names anyway).
* Reimplemented from KDirNotify.